@@ -36,15 +36,12 @@
 #include "empathy-contact.h"
 
 #define EMPATHY_GET_PRIV(obj,type) ((type##Priv *) ((type *) obj)->priv)
-#define EMP_STR_EMPTY(x) ((x) == NULL || (x)[0] == '\0')
 
 G_BEGIN_DECLS
 
 void empathy_init (void);
 
 /* XML */
-gboolean empathy_xml_validate_from_resource (xmlDoc *doc,
-    const gchar *dtd_resourcename);
 xmlNodePtr empathy_xml_node_get_child (xmlNodePtr node,
     const gchar *child_name);
 xmlChar * empathy_xml_node_get_child_content (xmlNodePtr node,
@@ -60,25 +57,17 @@ const gchar * empathy_presence_to_str (TpConnectionPresenceType presence);
 TpConnectionPresenceType empathy_presence_from_str (const gchar *str);
 gchar * empathy_file_lookup (const gchar *filename,
     const gchar *subdir);
-gboolean empathy_check_available_state (void);
 gint empathy_uint_compare (gconstpointer a,
     gconstpointer b);
 
 const gchar * empathy_account_get_error_message (TpAccount *account,
     gboolean *user_requested);
 
-gchar *empathy_protocol_icon_name (const gchar *protocol);
-const gchar *empathy_protocol_name_to_display_name (const gchar *proto_name);
-const gchar *empathy_service_name_to_display_name (const gchar *proto_name);
-
 #define EMPATHY_ARRAY_TYPE_OBJECT (empathy_type_dbus_ao ())
 GType empathy_type_dbus_ao (void);
 
 gboolean empathy_account_manager_get_accounts_connected (gboolean *connecting);
 
-void empathy_connect_new_account (TpAccount *account,
-    TpAccountManager *account_manager);
-
 TpConnectionPresenceType empathy_folks_presence_type_to_tp (
     FolksPresenceType type);
 gboolean empathy_folks_individual_contains_contact (
@@ -102,8 +91,6 @@ gchar *empathy_format_currency (gint amount,
     guint scale,
     const gchar *currency);
 
-gboolean empathy_account_has_uri_scheme_tel (TpAccount *account);
-
 TpContact * empathy_get_tp_contact_for_individual (FolksIndividual *individual,
     TpConnection *conn);
 
@@ -130,51 +117,6 @@ GVariant * empathy_boxed_to_variant (GType gtype,
     const gchar *variant_type,
     gpointer boxed);
 
-/* Copied from wocky/wocky-utils.h */
-
-#define empathy_implement_finish_void(source, tag) \
-    if (g_simple_async_result_propagate_error (\
-      G_SIMPLE_ASYNC_RESULT (result), error)) \
-      return FALSE; \
-    g_return_val_if_fail (g_simple_async_result_is_valid (result, \
-            G_OBJECT(source), tag), \
-        FALSE); \
-    return TRUE;
-
-#define empathy_implement_finish_copy_pointer(source, tag, copy_func, \
-    out_param) \
-    GSimpleAsyncResult *_simple; \
-    _simple = (GSimpleAsyncResult *) result; \
-    if (g_simple_async_result_propagate_error (_simple, error)) \
-      return FALSE; \
-    g_return_val_if_fail (g_simple_async_result_is_valid (result, \
-            G_OBJECT (source), tag), \
-        FALSE); \
-    if (out_param != NULL) \
-      *out_param = copy_func ( \
-          g_simple_async_result_get_op_res_gpointer (_simple)); \
-    return TRUE;
-
-#define empathy_implement_finish_return_copy_pointer(source, tag, copy_func) \
-    GSimpleAsyncResult *_simple; \
-    _simple = (GSimpleAsyncResult *) result; \
-    if (g_simple_async_result_propagate_error (_simple, error)) \
-      return NULL; \
-    g_return_val_if_fail (g_simple_async_result_is_valid (result, \
-            G_OBJECT (source), tag), \
-        NULL); \
-    return copy_func (g_simple_async_result_get_op_res_gpointer (_simple));
-
-#define empathy_implement_finish_return_pointer(source, tag) \
-    GSimpleAsyncResult *_simple; \
-    _simple = (GSimpleAsyncResult *) result; \
-    if (g_simple_async_result_propagate_error (_simple, error)) \
-      return NULL; \
-    g_return_val_if_fail (g_simple_async_result_is_valid (result, \
-            G_OBJECT (source), tag), \
-        NULL); \
-    return g_simple_async_result_get_op_res_gpointer (_simple);
-
 G_END_DECLS
 
 #endif /*  __EMPATHY_UTILS_H__ */
